@@ -45,10 +45,11 @@ class I2AChatApiClient:
         else:
             raise Exception(f'Ping attempt at {url} has failed. {self._status_code_message(response)}')
 
-    def open_session(self, device_identifier: str, application_user_identifier: str, custom_data=None):
+    def open_session(self, device_identifier: str, fcm_token: str, application_user_identifier: str, custom_data=None):
         """
         Creates new session
         :param device_identifier: str
+        :param fcm_token: str
         :param application_user_identifier: str
         :param custom_data: dict -> This data will be added to every message in websocket
         :return: token: str
@@ -58,6 +59,7 @@ class I2AChatApiClient:
         url = self._get_full_url('session/open-session/')
         data = {
             'device_identifier': device_identifier,
+            'fcm_token': fcm_token,
             'application_user_identifier': application_user_identifier,
             'custom_data': json.dumps(custom_data)
         }
